==> dojo-1.9.4.tgz: package/cldr/nls/he/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו'",
		"ש'"
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"quarters-standAlone-narrow": [
		"ר1",
		"ר2",
		"ר3",
		"ר4"
	],
	"field-weekday": "יום בשבוע",
	"dateFormatItem-yQQQ": "y QQQ",
	"dateFormatItem-yMEd": "E, d/M/y",
	"dateFormatItem-GyMMMEd": "E, d בMMM y G",
	"dateFormatItem-MMMEd": "E, d בMMM",
	"eraNarrow": [
		"לפנה״ס",
		"לסה״נ"
	],
	"dateFormatItem-yMM": "MM/y",
	"days-format-short": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו'",
		"ש'"
	],
	"dateFormat-long": "d בMMMM y",
	"months-format-wide": [
		"ינואר",
		"פברואר",
		"מרץ",
		"אפריל",
		"מאי",
		"יוני",
		"יולי",
		"אוגוסט",
		"ספטמבר",
		"אוקטובר",
		"נובמבר",
		"דצמבר"
	],
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "אחה״צ",
	"dateFormat-full": "EEEE, d בMMMM y",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yMd": "d.M.y",
	"field-era": "תקופה",
	"dateFormatItem-yM": "M.y",
	"months-standAlone-wide": [
		"ינואר",
		"פברואר",
		"מרץ",
		"אפריל",
		"מאי",
		"יוני",
		"יולי",
		"אוגוסט",
		"ספטמבר",
		"אוקטובר",
		"נובמבר",
		"דצמבר"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"dateFormatItem-yQQQQ": "y QQQQ",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "שנה",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "שעה",
	"months-format-abbr": [
		"ינו",
		"פבר",
		"מרץ",
		"אפר",
		"מאי",
		"יונ",
		"יול",
		"אוג",
		"ספט",
		"אוק",
		"נוב",
		"דצמ"
	],
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "היום",
	"field-day-relative+1": "מחר",
	"dateFormatItem-GyMMMd": "d בMMM y G",
	"field-day-relative+2": "מחרתיים",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"ינו׳",
		"פבר׳",
		"מרץ",
		"אפר׳",
		"מאי",
		"יונ׳",
		"יול׳",
		"אוג׳",
		"ספט׳",
		"אוק׳",
		"נוב׳",
		"דצמ׳"
	],
	"quarters-format-abbr": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"quarters-standAlone-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"timeFormat-medium": "HH:mm:ss",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"eraAbbr": [
		"לפנה״ס",
		"לסה״נ"
	],
	"field-minute": "דקה",
	"field-dayperiod": "לפה״צ/אחה״צ",
	"days-standAlone-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "אתמול",
	"dateFormatItem-h": "‏h a",
	"field-day-relative+-2": "שלשום",
	"dateFormatItem-MMMd": "d בMMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-day": "יום",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"field-zone": "אזור",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "שנה שעברה",
	"field-month-relative+-1": "חודש שעבר",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"dateFormatItem-yMMMd": "d בMMM y",
	"eraNames": [
		"לפני הספירה",
		"לספירה"
	],
	"days-format-narrow": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו׳",
		"ש׳"
	],
	"field-month": "חודש",
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו",
		"ש"
	],
	"dateFormatItem-MMM": "LLL",
	"dayPeriods-format-wide-am": "לפנה״צ",
	"dateFormat-short": "dd/MM/yy",
	"field-second": "שנייה",
	"dateFormatItem-yMMMEd": "E, d בMMM y",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "חודש הבא",
	"dateFormatItem-Ed": "E ה-d",
	"field-week": "שבוע",
	"dateFormat-medium": "d בMMM y",
	"field-year-relative+0": "השנה",
	"field-week-relative+-1": "שבוע שעבר",
	"field-year-relative+1": "שנה הבאה",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "שבוע הבא"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/he/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-second-relative+0": "עכשיו",
	"quarters-standAlone-narrow": [
		"ר1",
		"ר2",
		"ר3",
		"ר4"
	],
	"field-weekday": "יום בשבוע",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E, d.M.y",
	"field-wed-relative+0": "יום רביעי",
	"field-wed-relative+1": "יום רביעי הבא",
	"dateFormatItem-GyMMMEd": "E, d בMMM y G",
	"dateFormatItem-MMMEd": "E, d בMMM",
	"eraNarrow": [
		"לפנה״ס",
		"לספירה"
	],
	"dateFormatItem-yMM": "M.y",
	"field-tue-relative+-1": "יום שלישי שעבר",
	"days-format-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormat-long": "d בMMMM y",
	"field-fri-relative+-1": "יום שישי שעבר",
	"field-wed-relative+-1": "יום רביעי שעבר",
	"months-format-wide": [
		"ינואר",
		"פברואר",
		"מרץ",
		"אפריל",
		"מאי",
		"יוני",
		"יולי",
		"אוגוסט",
		"ספטמבר",
		"אוקטובר",
		"נובמבר",
		"דצמבר"
	],
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "אחה״צ",
	"dateFormat-full": "EEEE, d בMMMM y",
	"field-thu-relative+-1": "יום חמישי שעבר",
	"dateFormatItem-Md": "d.M",
	"dateFormatItem-yMd": "d.M.y",
	"field-era": "תקופה",
	"dateFormatItem-yM": "M.y",
	"months-standAlone-wide": [
		"ינואר",
		"פברואר",
		"מרץ",
		"אפריל",
		"מאי",
		"יוני",
		"יולי",
		"אוגוסט",
		"ספטמבר",
		"אוקטובר",
		"נובמבר",
		"דצמבר"
	],
	"timeFormat-short": "H:mm",
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"timeFormat-long": "H:mm:ss z",
	"field-year": "שנה",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "שעה",
	"months-format-abbr": [
		"ינו׳",
		"פבר׳",
		"מרץ",
		"אפר׳",
		"מאי",
		"יוני",
		"יולי",
		"אוג׳",
		"ספט׳",
		"אוק׳",
		"נוב׳",
		"דצמ׳"
	],
	"field-sat-relative+0": "יום שבת",
	"field-sat-relative+1": "יום שבת הבא",
	"timeFormat-full": "H:mm:ss zzzz",
	"field-day-relative+0": "היום",
	"field-thu-relative+0": "יום חמישי",
	"field-day-relative+1": "מחר",
	"field-thu-relative+1": "יום חמישי הבא",
	"dateFormatItem-GyMMMd": "d בMMM y G",
	"field-day-relative+2": "מחרתיים",
	"dateFormatItem-H": "H",
	"months-standAlone-abbr": [
		"ינו׳",
		"פבר׳",
		"מרץ",
		"אפר׳",
		"מאי",
		"יוני",
		"יולי",
		"אוג׳",
		"ספט׳",
		"אוק׳",
		"נוב׳",
		"דצמ׳"
	],
	"quarters-format-abbr": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"quarters-standAlone-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"timeFormat-medium": "H:mm:ss",
	"field-sun-relative+0": "יום ראשון",
	"dateFormatItem-Hm": "H:mm",
	"field-sun-relative+1": "יום ראשון הבא",
	"quarters-standAlone-abbr": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"eraAbbr": [
		"לפנה״ס",
		"לספירה"
	],
	"field-minute": "דקה",
	"field-dayperiod": "לפנה״צ/אחה״צ",
	"days-standAlone-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "אתמול",
	"dateFormatItem-h": "‏h a",
	"dateTimeFormat-long": "{1} בשעה {0}",
	"field-day-relative+-2": "שלשום",
	"dateFormatItem-MMMd": "d בMMM",
	"dateFormatItem-MEd": "E, d.M",
	"dateTimeFormat-full": "{1} בשעה {0}",
	"field-fri-relative+0": "יום שישי",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-fri-relative+1": "יום שישי הבא",
	"field-day": "יום",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"field-zone": "אזור",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "השנה שעברה",
	"field-month-relative+-1": "החודש שעבר",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"dateFormatItem-yMMMd": "d בMMM y",
	"eraNames": [
		"לפני הספירה",
		"לספירה"
	],
	"days-format-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "חודש",
	"field-tue-relative+0": "יום שלישי",
	"field-tue-relative+1": "יום שלישי הבא",
	"dayPeriods-format-wide-am": "לפנה״צ",
	"dateFormatItem-EHm": "E H:mm",
	"field-mon-relative+0": "יום שני",
	"field-mon-relative+1": "יום שני הבא",
	"dateFormat-short": "d.M.y",
	"dateFormatItem-EHms": "E H:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "שנייה",
	"field-sat-relative+-1": "יום שבת שעבר",
	"dateFormatItem-yMMMEd": "E, d בMMM y",
	"field-sun-relative+-1": "יום ראשון שעבר",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "החודש הבא",
	"dateFormatItem-Ed": "E ה-d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "שבוע",
	"dateFormat-medium": "d בMMM y",
	"field-year-relative+0": "השנה",
	"field-week-relative+-1": "השבוע שעבר",
	"field-year-relative+1": "השנה הבאה",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "H:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "יום שני שעבר",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "השבוע הבא"
}
//end v1.x content
);
